@@ -786,7 +786,7 @@ gok_spy_concatenate_child_names (Accessible *parent, gint depth)
 				{
 					if (tmp) 
 					{
-						name = g_strconcat (tmp, "", childname, NULL);
+						name = g_strconcat (tmp, " ", childname, NULL);
 						g_free (tmp);
 					}
 					else 
@@ -1984,6 +1984,24 @@ GSList* gok_spy_append_node (GSList* nodes,
 		}
 	}
 	
+    /* We consider it safe enough to provide a name for nameless Selections */
+    if ((pName == NULL) && Accessible_isSelection(pAccessible)) {
+        gchar* rolename;
+        rolename = Accessible_getRoleName (pAccessible);
+        pName = g_strdup (rolename);
+        nodes = gok_spy_add_node (nodes, pAccessible, flags, 0, pName);
+        SPI_freeString (rolename);
+    }
+
+   
+    if ((pName == NULL) && gok_main_get_debug_nameless()) {
+        gchar* rolename;
+        rolename = Accessible_getRoleName (pAccessible);
+        pName = g_strconcat ("NAMELESS ",rolename,"!",NULL);
+        nodes = gok_spy_add_node (nodes, pAccessible, flags, 0, pName);
+        SPI_freeString (rolename);
+     }
+
 	gok_log_leave();
 
 	return nodes;
