@@ -133,6 +133,7 @@ typedef struct _GokArgs {
 	char *geometry;
 	int geometry_bitmask;
 	gboolean is_login;
+	gboolean debug_nameless;
 	int remember_geometry;
 	int display_settings_dialog;
 	gboolean use_extras;
@@ -250,6 +251,15 @@ static struct poptOption options[] = {
 		NULL
 	},
 
+	{
+		"debugnameless", 
+		'\0', 
+		POPT_ARG_NONE, 
+		&gok_args.debug_nameless, 
+		0,
+		N_("GOK will display keys for nameless GUI. Useful for debugging."),
+		NULL
+	},
 
 	{
 		"remembergeometry", 
@@ -347,6 +357,7 @@ gok_args_init (GokArgs *args)
 	args->geometry = NULL;
 	args->geometry_bitmask;
 	args->is_login = 0;
+	args->debug_nameless = FALSE;
 	args->remember_geometry = FALSE;
 	args->display_settings_dialog = FALSE;
 	args->use_extras = FALSE;
@@ -2917,7 +2928,9 @@ void check_accessibility_cb ( GObject* o, gpointer* data )
 {
 	GnomeClient *client;
 
-	gtk_widget_destroy(acd);	
+	if (acd) { 
+	    gtk_widget_destroy(acd); acd = NULL; 
+	}	
 	
 	if (strcmp((gchar*)data,"logout") == 0) {
 		gok_gconf_set_bool ( gok_data_get_gconf_client(),
@@ -2954,8 +2967,10 @@ gok_main_help_cb (gpointer data)
 void
 gok_main_close_warning ()
 {
-        gtk_widget_destroy (_corepointer_warning);
-	_corepointer_warning = NULL;
+        if (_corepointer_warning) {
+                gtk_widget_destroy (_corepointer_warning);
+	        _corepointer_warning = NULL;
+        }
 } 
 
 void
@@ -3121,3 +3136,9 @@ gok_main_check_accessibility ()
 		
 	}
 }
+
+gboolean
+gok_main_get_debug_nameless ()
+{
+	return gok_args.debug_nameless;
+}
